Welcome to the Prevision.io Python SDK
======================================

[![Documentation Status](https://readthedocs.org/projects/pip/badge/?version=stable)](https://pip.pypa.io/en/stable/?badge=stable)


The Prevision.io Python SDK allows to easily use [Prevision.io](https://prevision.io/) 
APIs to train, predict and automate pipelines with sklearn-like interface.

The full documentation is available [here](https://prevision-python.readthedocs.io/en/latest/).


# Installation
```
git clone https://github.com/previsionio/prevision-python
cd prevision-python
python setup.py install
```

---

## [Sign up for a free trial](https://cloud.prevision.io) 
